Exception: ADAM6050::Session::UnknownSender

Inherits:
InvalidSender show all
Defined in:
lib/adam6050/session.rb

Overview

The unknown sender error is used to signify that a sender has not yet authenticated within the session.

Method Summary

Methods inherited from InvalidSender

#initialize

Constructor Details

This class inherits a constructor from ADAM6050::Session::InvalidSender